import{S as r,i as _,s as u,F as f,k as c,l as m,m as p,h as i,n as d,b as h,G as $,H as v,I as y,f as g,t as b}from"../../chunks/index-ca05d6de.js";function I(n){let s,a;const o=n[1].default,e=f(o,n,n[0],null);return{c(){s=c("main"),e&&e.c(),this.h()},l(t){s=m(t,"MAIN",{class:!0});var l=p(s);e&&e.l(l),l.forEach(i),this.h()},h(){d(s,"class","svelte-1nc797j")},m(t,l){h(t,s,l),e&&e.m(s,null),a=!0},p(t,[l]){e&&e.p&&(!a||l&1)&&$(e,o,t,t[0],a?y(o,t[0],l,null):v(t[0]),null)},i(t){a||(g(e,t),a=!0)},o(t){b(e,t),a=!1},d(t){t&&i(s),e&&e.d(t)}}}function S(n,s,a){let{$$slots:o={},$$scope:e}=s;return n.$$set=t=>{"$$scope"in t&&a(0,e=t.$$scope)},[e,o]}class k extends r{constructor(s){super(),_(this,s,S,I,u,{})}}export{k as default};
